@@ -19,6 +19,7 @@ class TripGroupManager;
 class StatisticsItem
 {
     Q_GADGET
+    Q_PROPERTY(bool hasData MEMBER m_hasData CONSTANT)
     Q_PROPERTY(QString label MEMBER m_label CONSTANT)
     Q_PROPERTY(QString value MEMBER m_value CONSTANT)
     Q_PROPERTY(Trend trend MEMBER m_trend CONSTANT)
@@ -33,12 +34,13 @@ public:
     Q_ENUM(Trend)
 
     StatisticsItem();
-    explicit StatisticsItem(const QString &label, const QString &value, StatisticsItem::Trend trend = TrendUnknown);
+    explicit StatisticsItem(const QString &label, const QString &value, StatisticsItem::Trend trend = TrendUnknown, bool hasData = true);
     ~StatisticsItem();
 
     QString m_label;
     QString m_value;
     Trend m_trend = TrendUnknown;
+    bool m_hasData = true;
 };
 
 Q_DECLARE_METATYPE(StatisticsItem)
@@ -69,6 +71,10 @@ class StatisticsModel : public QObject
     Q_PROPERTY(StatisticsItem carDistance READ carDistance NOTIFY changed)
     Q_PROPERTY(StatisticsItem carCO2 READ carCO2 NOTIFY changed)
 
+    Q_PROPERTY(StatisticsItem boatCount READ boatCount NOTIFY changed)
+    Q_PROPERTY(StatisticsItem boatDistance READ boatDistance NOTIFY changed)
+    Q_PROPERTY(StatisticsItem boatCO2 READ boatCO2 NOTIFY changed)
+
     Q_PROPERTY(ReservationManager* reservationManager READ reservationManager WRITE setReservationManager NOTIFY setupChanged)
     Q_PROPERTY(TripGroupManager* tripGroupManager READ tripGroupManager WRITE setTripGroupManager NOTIFY setupChanged)
 
@@ -105,6 +111,10 @@ public:
     StatisticsItem carDistance() const;
     StatisticsItem carCO2() const;
 
+    StatisticsItem boatCount() const;
+    StatisticsItem boatDistance() const;
+    StatisticsItem boatCO2() const;
+
 Q_SIGNALS:
     void setupChanged();
     void changed();
@@ -117,7 +127,7 @@ private:
     QDate m_begin;
     QDate m_end;
 
-    enum AggregateType { Total, Flight, Train, Bus, Car, AGGREGATE_TYPE_COUNT };
+    enum AggregateType { Total, Flight, Train, Bus, Car, Boat, AGGREGATE_TYPE_COUNT };
     enum StatType { TripCount, Distance, CO2, STAT_TYPE_COUNT };
 
     AggregateType typeForReservation(const QVariant &res) const;
@@ -131,6 +141,7 @@ private:
 
     int m_statData[AGGREGATE_TYPE_COUNT][STAT_TYPE_COUNT];
     int m_prevStatData[AGGREGATE_TYPE_COUNT][STAT_TYPE_COUNT];
+    bool m_hasData[AGGREGATE_TYPE_COUNT];
     int m_hotelCount = 0;
     int m_prevHotelCount = 0;
     int m_tripGroupCount = 0;
